config_from_msg

Function config_from_msg 

pub fn config_from_msg(
    msg: &BacktestConfigMsg,
    registry: &SymbolRegistry,
    symbols: &[String],
) -> Result<BacktestConfig>
Convert the wire config message into the internal BacktestConfig.

registry and symbols are used to populate per-symbol contract sizes and symbol specs from the symbol registry metadata.