pub fn load_run_file(path: &Path) -> Result<StrategyClientRequest, String>Expand description
Read a run file and the documents it names, and build the request it describes.
pub fn load_run_file(path: &Path) -> Result<StrategyClientRequest, String>Read a run file and the documents it names, and build the request it describes.